/* GObject - GLib Type, Object, Parameter and Signal Library
 *
 * Copyright (C) 2015-2022 Christian Hergert <christian@hergert.me>
 * Copyright (C) 2015 Garrett Regier <garrettregier@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#ifndef __GTK_SIGNAL_GROUP_H__
#define __GTK_SIGNAL_GROUP_H__

#include <glib-object.h>

G_BEGIN_DECLS

#define GTK_SIGNAL_GROUP(obj)    (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_SIGNAL_GROUP, GtkSignalGroup))
#define GTK_IS_SIGNAL_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_SIGNAL_GROUP))
#define GTK_TYPE_SIGNAL_GROUP    (gtk_signal_group_get_type())

typedef struct _GtkSignalGroup GtkSignalGroup;

GType         gtk_signal_group_get_type        (void) G_GNUC_CONST;
GtkSignalGroup *gtk_signal_group_new             (GType           target_type);
void          gtk_signal_group_set_target      (GtkSignalGroup   *self,
						gpointer          target);
gpointer      gtk_signal_group_dup_target      (GtkSignalGroup   *self);
void          gtk_signal_group_block           (GtkSignalGroup   *self);
void          gtk_signal_group_unblock         (GtkSignalGroup   *self);
void          gtk_signal_group_connect_closure (GtkSignalGroup   *self,
						const gchar      *detailed_signal,
						GClosure         *closure,
						gboolean          after);
void          gtk_signal_group_connect_object  (GtkSignalGroup   *self,
						const gchar      *detailed_signal,
						GCallback         c_handler,
						gpointer          object,
						GConnectFlags     flags);
void          gtk_signal_group_connect_data    (GtkSignalGroup   *self,
						const gchar      *detailed_signal,
						GCallback         c_handler,
						gpointer          data,
						GClosureNotify    notify,
						GConnectFlags     flags);
void          gtk_signal_group_connect         (GtkSignalGroup   *self,
						const gchar      *detailed_signal,
						GCallback         c_handler,
						gpointer          data);
void          gtk_signal_group_connect_after   (GtkSignalGroup   *self,
						const gchar      *detailed_signal,
						GCallback         c_handler,
						gpointer          data);
void          gtk_signal_group_connect_swapped (GtkSignalGroup   *self,
						const gchar      *detailed_signal,
						GCallback         c_handler,
						gpointer          data);

G_END_DECLS

#endif /* __GTK_SIGNAL_GROUP_H__ */
